@@ -1,4 +1,4 @@
-/* Copyright (C) 2003 MySQL AB
+/* Copyright (c) 2003, 2014, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,12 +11,10 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */
 
 /* Wait until a program dies */
 
-#ifndef __NETWARE__
-
 #include <my_global.h>
 #include <m_string.h>
 #include <my_sys.h>
@@ -66,6 +64,10 @@ int main(int argc, char *argv[])
 
   progname= argv[0];
 
+  fprintf(stderr, 
+	  "Warning: %s is deprecated and will be removed in a future version.\n", 
+	  progname);
+
   if (handle_options(&argc, &argv, my_long_options, get_one_option))
     exit(-1);
   if (!argv[0] || !argv[1] || (pid= atoi(argv[0])) <= 0 ||
@@ -103,15 +105,3 @@ void usage(void)
   my_print_help(my_long_options);
   exit(-1);
 }
-
-#else
-
-#include <stdio.h>
-
-main()
-{
-	fprintf(stderr,"This tool has not been ported to NetWare\n");
-	return 0;
-}
-
-#endif /* __NETWARE__ */
